Training & Testing

# **Force-Velocity Profi le: Imbalance Determination and** **Eff ect on Lower Limb Ballistic Performance**

**Authors** **P. Samozino** **\[1\]** **, P. Edouard** **\[2\]\[, \]\[3\]** **, S. Sangnier** **\[4\]\[, \]\[5\]** **, M. Brughelli** **\[6\]** **, P. Gimenez** **\[3\]** **, J.-B. Morin** **\[3\]**

**Affi liations** Affi liation addresses are listed at the end of the article

Key words

- \[ ▶ \] jump

- \[ ▶ \] muscle mechanical

properties

- \[ ▶ \] maximal power output

- \[ ▶ \] optimal force-velocity profi le

- \[ ▶ \] explosive push-off

- \[ ▶ \] strength training

**accepted after revision**
August 02, 2013

Bibliography
**DOI** <http://dx.doi.org/>
10.1055/s-0033-1354382
Published online: 2013

Int J Sports Med
© Georg Thieme
Verlag KG Stuttgart · New York

ISSN 0172-4622

Correspondence

_Dr. Pierre Samozino_

Laboratory of Exercise
Physiology (EA4338)
Université de Savoie

UFR CISM – Technolac

Le Bourget du Lac 73376

France

Tel.: + 33/4/79 75 81 77
Fax: + 33/4/79 75 81 48
<pierre.samozino@univ-savoie.fr>

Abstract

This study sought to lend experimental support
to the theoretical infl uence of force-velocity (F-v)
mechanical profi le on jumping performance
independently from the eff ect of maximal power
output ( _Pmax_ ). 48 high-level athletes (soccer players, sprinters, rugby players) performed maximal
squat jumps with additional loads from 0 to 100 %
of body mass. During each jump, mean force,
velocity and power output were obtained using a
simple computation method based on fl ight time,
and then used to determine individual linear F-v

relationships and _Pmax_ values. Actual and optimal
F-v profi les were computed for each subject to
quantify mechanical F-v imbalance. A multiple
regression analysis showed, with a high-adjust

Introduction

Ballistic performances are a key factor in numerous sport activities and can be defi ned as the
ability to accelerate a mass as much as possible in
the shortest time possible, be it one’s own body
mass (e. g. sprints or jumps) or an external mass
(e. g. throws). Success in such performances has
been closely related to the maximal power output ( _Pmax_ ) limbs can develop \[ 11, 32, 33 \] . Instantaneous power output is the product of the
external force developed by velocity. A recently
validated theoretical integrative approach of
jumping showed that ballistic performance is
also infl uenced by the force-velocity (F-v)
mechanical profi le (henceforth referred to as “F-v
profi le”) of the lower limb neuromuscular system (henceforth referred to as “lower limbs”),
independently from _Pmax_ \[ 30 \] . This F-v profi le,
normalized to body mass, represents the ratio
between the external force developed and velocity maximal capabilities, and can be determined
by the slope of the F-v relationship \[ 30 \] . The relationship between performance and F-v profi le is

ment quality (r² = 0.931, P \< 0.001, SEE = 0.015 m),
signifi cant contributions of _Pmax_, F-v imbalance
and lower limb extension range ( _hPO_ ) to explain
interindividual diff erences in jumping performance (P \< 0.001) with positive regression coeffi cients for _Pmax_ and _hPO_ and a negative one for
F-v imbalance. This experimentally supports that
ballistic performance depends, in addition to
_Pmax_, on the F–v profi le of lower limbs. This adds
support to the actual existence of an individual
optimal F-v profi le that maximizes jumping performance, a F-v imbalance being associated to a
lower performance. These results have potential
strong applications in the fi eld of strength and
conditioning.

curvilinear (inverse U shape) with an apex corresponding to an optimal F-v profi le maximizing
performance. For each individual, an optimal F-v
profi le can then be accurately determined and
represents the best balance between its force and
velocity capabilities. For a given _Pmax_, an unfavorable balance between force and velocity qualities can lead to a ~30 % lower performance \[ 30 \] .
Thus, considering both _Pmax_ and the individual
F-v profi le compared to the optimal one might be
of great interest for exploring ballistic performances and optimizing athletic training.
The aforementioned theoretical approach took
account of both movement dynamics of the body
center of mass during jumping and external
mechanical limits of the entire lower limb neu
romuscular system \[ 29, 30 \] . The latter was considered as a complete force generator system
characterized by _Pmax_, F-v profi le and range of
motion values. This approach was based on equations recently validated in comparison to experimental measurements \[ 30 \] . However, no
experimental data has thus far supported the
theoretical infl uence of F-v profi le on ballistic

Samozino P et al. Force-Velocity Profi le: Imbalance Determination … Int J Sports Med

Training & Testing

performance and the existence of an individual optimal F-v profi le value, mainly due to (i) the curvilinear relationship between
F-v profi le and performance preventing direct correlation analysis and (ii) the diffi culty in experimentally isolating the eff ect of
the F-v profi le independently from the large eff ect of _Pmax_ .
Indeed, these 2 variables, though theoretically independent,
often change together similarly in studies testing athletes with
diff erent training backgrounds \[ 32, 33 \] or diff erent training protocols \[ 6, 7, 10, 15, 22 \] . The aim of this study was to bring experimental support to the theoretical infl uence of F-v profi le on
jumping performance independently from the eff ect of _Pmax_ . In
addition to the previously demonstrated positive relation with
_Pmax_, it was hypothesized that jumping performance would be
negatively related to the magnitude of the F-v imbalance.

Method

**Population**
48 international and national-level athletes (31 soccer players,
11 sprinters and 6 rugby players) participated in the study (age
(mean ± SD) 20.9 ± 4.4 years; body mass 75.8 ± 12.0 kg; height
1.79 ± 0.06 m). All subjects were free of musculoskeletal pain or
injury during the period of the study and gave their written
informed consent to participate in this study after being
informed about the procedures, which complied with the Declaration of Helsinki. This study met the ethical standards of the
International Journal of Sports Medicine \[ 16 \] .

**Procedure and data analysis**
Each subject performed one session of maximal squat jump tests
to determine their _Pmax_, F-v profi le and F-v imbalance. For each
subject, the vertical distance between the ground and the right
leg great trochanter was measured in a 90 °-knee angle crouch
position \[ 28 \] . After a 10-min warm-up, each subject performed
maximal squat jumps in 5 randomized loading conditions: additional loads of 0, 25, 50, 75 and 100 % of their body mass. Subjects stood still holding a barbell across their shoulders for
additional-loads conditions or with arms crossed on the torso

for the unloaded condition. They then initiated the squat jump
with a downward movement to reach their individual 90 °-knee

angle starting crouch position (measured beforehand as the vertical distance between the ground and the right leg great trochanter, and checked by the experimenter using a vertical rule
before trials \[ 28 \] ). After maintaining this position for at least 1 s,
they were asked to apply force as rapidly as possible and to jump
for maximum height. Countermovement was verbally restricted
and carefully checked. Subjects were instructed to keep constant
downward pressure on the barbell throughout the jump with
the chest upright, and asked to touch down the ground in the
same leg position as they took off, i. e., extended leg in foot
plantar fl exion. If these requirements were not met, the trial was
repeated. Subjects had to perform 2 correct trials by condition,
only the best one being used in the analysis. Before this session,
subjects were allowed enough supervised practice to correctly
perform squat jumps without countermovement.
During each trial, the mean vertical force developed by the lower
limbs during push-off ( _Fabs_, absolute force in N) and the corresponding mean center of mass (CM) vertical velocity ( ~~_v_~~, in
m.s \[ − 1\] ) were determined using the equations and the methodology proposed and validated by Samozino et al. \[ 28 \] :

= _mg_ ⎛ _h_ +

⎝ \[⎜\] _hPO_

⎞

\[1\] ⎠ \[⎟\]

1

2

_Fabs_ = _mg_ ⎛ _h_

\[⎜\] _h_

⎝ \[⎜\]

~~_v_~~ = _gh_
2

with _m_ being the total mass (sum of body mass + additional load,
in kg), _g_ the gravitational acceleration (9.81 m.s \[ − 2\] ), _hPO_ the vertical distance covered by the CM during push-off corresponding to
the extension range of lower limbs (in m) and _h_ the jump height
(in m). Here, _hPO_ was determined as the diff erence between the
extended lower limb length with maximal foot plantar fl exion
(great trochanter-toe distance) and the vertical distance
between the great trochanter and ground in the starting position. _h_ was obtained from fl ight time applying fundamental laws
of dynamics \[ 3 \], fl ight time being measured using an infrared
timing system (Optojump, Microgate, Bolzano, Italy). For the following analyses, force values were normalized to the subject’s
body mass (i. e., the moving mass during unloaded jumping
movements), since jumping performance has been directly
related to normalized force ( _F_ in N.kg \[ − 1\], \[ 29 \] ). From _F_ and
~~_v_~~ values, individual linear F-v relationships were determined
by least-squares linear regressions \[ 5, 27, 33 \] to obtain for each
subject (i) the F-v profi le normalized to body mass ( _SFv_, slope of
the F-v curve, in N.s.kg \[ − 1\] .m \[ − 1\] ) and (ii) _Pmax_ (in W.kg \[ − 1\] ) computed here by:

_P_ = _F v_ 0. 0

3

max

= 0. 0
4

with _F_ 0 and _v_ 0 being the theoretical maximal force the lower
limbs can produce at null velocity (extrapolated intercept with
force-axis, in N.kg \[ − 1\] ) and the theoretical maximal velocity at
which lower limbs can extend under zero load (extrapolated
intercept with velocity-axis, in m.s \[ − 1\] ), respectively \[ 30, 32 \] . Note
that _Pmax_ must also be expressed here relative to the body mass
in unloaded condition (in W.kg \[ − 1\], \[ 30 \] ), and not relative to body
mass exponent 2/3 as suggested by scaling models and experimental data when the aim is to scale muscle power to the body
size \[ 23 \] . From _Pmax_ and _hPO_ values, the theoretical optimal _SFv_
( _SFvopt_ normalized to body mass, in N.s.kg \[ − 1\] .m \[ − 1\] ) maximizing
jumping performance were computed for each subject using
equations proposed by Samozino et al. (appendix section in
\[ 30 \] ). The F-v imbalance ( _FvIMB_, in %) were then individually
computed as:

_FvIMB_ = 100 1. − _S optFvSFv_

_Fv_

4

= 100 1. −

_Fv_

The hypothetic maximal jump each subject could reach if he
presented an optimal F-v profi le ( _hmax_, in m) was computed from
his actual _Pmax_ and _hPO_ values, and using the following equation
derived from previously validated equations \[ 29, 30 \] :

2

5

_h_
_h_ =

⎞

⎟
⎠

_g_

⎜
⎝

The theoretical loss of performance due to the F-v imbalance
was computed for each subject as the percent diff erence between
actual unloaded jump height and _hmax_ (in percentage of _hmax_ ).

Samozino P et al. Force-Velocity Profi le: Imbalance Determination … Int J Sports Med

**Table 1** Correlation matrix for all variables (n = 47, one outlier was removed).

_h_ : jump height; _Pmax_ : maximal power output; _SFv_ : Force-velocity mechanical profi le;

_FvIMB_ : Force-velocity imbalance; _hPO_ : lower limb extension range

**Table 2** Multiple regression analysis for the prediction of jump height
(n = 47, one outlier was removed).

**Multiple regression model** **r²** **SEE (m)** **P**

0.931 0.015 \< 0.001

**Independent variables** **Coeffi cient** **t** **P**

_**Pmax**_ 0.0122 23.0 \< 0.001

_**FvIMB**_ − 0.0810 − 5.92 \< 0.001
_**hPO**_ 0.617 13.9 \< 0.001

**Constant** − 0.174 − 7.13 \< 0.001

_SEE:_ Standard Error of Estimate; _Pmax:_ maximal power output; _FvIMB_ : Force-velocity

imbalance _; hPO_ : lower limb extension range

**Statistical analyses**
All data are presented as mean ± SD. Normality and homogeneity
of variance were checked before analyses. One highly strengthtrained subject had jump height, _Pmax_ and _FvIMB_ values more
than 3 SD beyond average values for the group, and was therefore considered as outlier for statistical analyses. The degree of
linear relationship between variables was examined using Pearson’s product moment correlation. To test the independent
implication of _Pmax_ and _FvIMB_ on jumping performance, a multi

Training & Testing

ple regression analysis was performed with maximal unloaded
jump height as the dependent variable, and _FvIMB_, _Pmax_ (normalized to body mass) and _hPO_ as independent variables. This multiple regression model was based on the previously proposed
theoretical approach \[ 30 \] . The eff ect of F-v profi le was tested in
regression analysis through _FvIMB_ since the relationship between
F-v profi le and performance is curvilinear, while that between
performance and _FvIMB_ should be simply decreasing. The criterion for statistical signifi cance was set at α = 0.05.

Results

Individual F-v relationships were well fi tted by linear regressions
(r² = 0.87–1.00; _P_ ≤ 0.05). ● \[ ▶ \] **Fig. 1** presents an F-v curve for a typical subject, compared to the theoretical F-v curve characterizing his optimal F-v profi le that would maximize his jumping
performance without changing _Pmax_ . Mean values ( ± SD) of maximal unloaded jump height, _hPO_, _Pmax_, _SFv_, _SFvopt_ and _FvIMB_
were 0.38 ± 0.06 m, 0.36 ± 0.05 m, 29.7 ± 6.13 W.kg \[ − 1\], − 11.6 ±
7.36 N.s.kg \[ − 1\] .m \[ − 1\], − 15.0 ± 1.30 N.s.kg \[ − 1\] .m \[ − 1\] and 42.6 ± 34.4 %,
respectively. When considering simple correlation analyses,
jumping performance was signifi cantly correlated to _Pmax_ and
_hPO_, but not to _SFv_ and _FvIMB_ ( ● \[ ▶ \] **Table 1** ). No simple correlation
was found between the 3 independent variables ( _Pmax_, _FvIMB_
and _hPO_ ). The multiple regression analysis indicated that, when
considered together, the 3 predictor variables accounted for a
signifi cant amount of jumping performance variability
(P \< 0.001, ● \[ ▶ \] **Table 2** ). Furthermore, the regression model
showed a high quality of adjustment (r² = 0.931, P \< 0.001) and
minimal error (SEE = 0.015 m) ( ● \[ ▶ \] **Table 2**,  ● \[ ▶ \] **Fig. 2** ). It should be
noted that, when only _Pmax_ and _hPO_ were considered as independent variables, the regression model also showed a good
quality of adjustment (r² = 0.875, SEE = 0.020, P \< 0.001), but
lower than that when _FvIMB_ was considered. The loss of performance due to individual F-v imbalance was 6.49 ± 6.25 %. ● \[ ▶ \] **Fig. 3**
presents the actual jump height reached by each subject ( _h_
expressed relatively to _hmax_ ) according to their F-v profi le ( _SFv_
expressed relative to their personal _SFvopt_ ), as well as the corresponding theoretical changes predicted by the model (equation
5 with _hPO_ and _Pmax_ values arbitrarily set to the average values for
the entire group).

Discussion

The main fi nding of this study is the signifi cant contribution of
mechanical F-v imbalance to explain jumping performance variability. This constitutes experimental support for (i) the infl uence of the normalized F-v profi le (characterized by the slope of
the F-v relationship, _SFv_ ) on jumping performance independently from the large eff ect of _Pmax_, and (ii) the existence of an
optimal F-v profi le maximizing performance for each individual.
These results lend experimental support to the previously proposed theoretical approach \[ 30 \] .
Simple correlations showed that jumping performance was
highly associated with lower limb maximal power output, as
previously observed with similar magnitude (e. g. \[ 13, 32, 33 \], _r_
ranging from 0.65 to 0.84), but not directly to _SFv_ or _FvIMB_ . This
confi rmed that jumping performance mainly depends on _Pmax_
\[ 30 \] . The absence of experimental correlation between performance and _SFv_ was expected knowing the theoretical curvilinear

Samozino P et al. Force-Velocity Profi le: Imbalance Determination … Int J Sports Med

Training & Testing

0.55

0.50

0.45

0.40

0.35

0.30

0.25

0.20

0.20 0.25

0.30 0.35 0.40 0.45 0.50 0.55 0.60

Jump height measured (m)

**Fig. 2** Correlation between model-predicted and measured jump
heights. Each point represents a subject: white points for soccer players,
grey points for sprinters and black points for rugby players. The outlier
(the point with a cross) was not considered in the correlation analysis. The
solid line represents the identity line.

120

100

80

60

40

20

0

_Velocity profile_ _Force profile_

**Fig. 3** Actual jump height reached in unloaded condition ( _h_ expressed
relatively to _hmax_ ) according to F-v profi le ( _SFv_ expressed relatively to their
personal _SFvopt_ ). Each point represents a subject: white points for soccer
players, grey points for sprinters and black points for rugby players (a
cross shows the outlier). The solid line represents theoretical changes
predicted by the model (equation 5 with _hPO_ and _Pmax_ values arbitrarily set
to the average values for the entire group).

relationship between these 2 variables \[ 30 \] . Since _Pmax_ and _FvIMB_
are independent in theory, which was not contradicted here
experimentally (absence of correlation between these 2 variables), the eff ect of _FvIMB_ on jumping performance can be biased
by the very large eff ect of _Pmax_ . However, the multiple regression
analysis, testing the eff ect of each independent variable independently from each other, showed that interindividual variability in jumping performance is partly explained by _FvIMB_ . For a
given _Pmax_, the higher _FvIMB_, the lower the jumping performance,
which validates our hypothesis. Subjects presented here _FvIMB_
ranging from 2.07 % (quasi perfect balance between force and
velocity qualities) to 94.3 % (very high F-v imbalance), and even
248 % for the outlier. These F-v imbalances concerned both F-v

profi les excessively oriented towards velocity capabilities (until
_FvIMB_ of 64.4 %) and F-v profi les excessively oriented towards

force qualities (until _FvIMB_ of 248 %, ● \[ ▶ \] **Fig. 3** ). A subject presenting a F-v imbalance (as computed here from _SFvopt_ maximizing
vertical jumps) means that he does not develop his _Pmax_ against
his body mass during a vertical jump \[ 30 \] . This could be related
to the Maximum Dynamic Output hypothesis proposed by Jaric
and Markovic \[ 19 \], which stated that the neuromuscular system
is optimized, and in turn develops _Pmax_, in ballistic movements
realized against its own body weight and inertia since it is likely
designed to work optimally against loads most usually supported and mobilized \[ 19, 24, 25 \] . However, when body mass is
mobilized horizontally (horizontal jumps or displacements), the
mechanical constraint to the movement is lower than the load

represented by body weight during a vertical jump. Consequently, individuals used to running horizontally (as most of the
present subjects, notably soccer players or sprinters, ● \[ ▶ \] **Fig. 3** )
can present optimal load-maximizing power during vertical
jumping lower than their own body mass and thus present an
F-v imbalance towards velocity qualities for vertical jumps. In
contrast, rugby players used to and trained to perform displacements against resistive forces and to mobilize high training loads
presented F-v imbalances towards force qualities, which is the
case here for 4 out of 6 rugby players ( ● \[ ▶ \] **Fig. 3** ). During the
present protocol, the latter developed their _Pmax_ during vertical
jumps against loads higher than their body mass (i. e., for additional loads from 25 to 100 % of their body mass). This would
explain the large range of F-v imbalance observed here and support the recently proposed and debated infl uence of training
history on the optimal load-maximizing power during vertical
jumps \[ 19, 21, 24 – 26 \] . Further studies are required to explore
the exact origins of these large individual diff erences in F-v
imbalance.

The negative eff ect of the F-v imbalance on performance was
quantifi ed for each subject through the diff erence between their
actual jump height reached during unloaded condition and the
maximal height they would have reached if they had presented
the same _Pmax_ with an optimal F-v profi le. The individual loss of
performance due to the F-v imbalance ranged from 0 for subjects presenting optimal profi le to ~30 % for the outlier ( ● \[ ▶ \] **Fig. 3** ),
which is in line with the theoretical simulations performed by
Samozino et al. \[ 30 \] . Furthermore, since _FvIMB_ is computed as the
diff erence between a subject’s theoretically optimal and actual
F-v profi les, the signifi cant implication of F-v imbalance in
jumping performance provides experimental support for the
actual existence of an optimal F-v profi le, specifi c to each individual, that maximizes jumping performance for a same given
_Pmax_ . This fi nding is of interest for better understanding the relationships between lower limb neuromuscular system mechanical properties and functional performance, notably for
optimizing sport performance and training considering individual F-v profi le in addition to _Pmax_ . The F-v profi le has been shown
to be sensitive to specifi c training and to the additional loads
used by athletes during strength training and conditioning:
moving light loads (e. g., \< 30 % of 1 repetition maximum) during
maximal eff ort to orient F-v profi le towards velocity qualities
and moving heavy loads ( > 75–80 % of 1 repetition maximum) to
improve strength capabilities \[ 7, 20 \] . Consequently, training
loads can be selected according to athlete’s individual F-v imbalance, which would lead to improved performance through both
an increase in _Pmax_ and an optimization of F-v profi le.
Simple correlations and multiple regressions showed that jumping performance was positively related to _hPO_ . Thus, for a given
_Pmax_ and F-v profi le, individuals with higher _hPO_ (i. e., higher

Samozino P et al. Force-Velocity Profi le: Imbalance Determination … Int J Sports Med

lower limb range of motion) presented higher performances
since they can develop a higher mechanical work during the
push-off phase. Even if this fi nding is not of great interest for
training purposes (since _hPO_ represents the personal optimal
lower limb range of motion), it aids in understanding interindividual and interspecies diff erences in jumping performance, as
previously discussed for humans with the infl uence of the starting position \[ 1, 12, 31 \], and for animals through the eff ect of hind
limb length or joint range of motion \[ 1, 14, 18 \] .
It is worth noting that multiple regression analysis determined
that 93.1 % of the variation in jumping performance could be
explained by variation in lower limb maximal power capabilities, F-v imbalance and lower limb extension range. In addition
to the very low SEE (1.5 cm), this represents a very high prediction quality of human performance, from only 3 lower limb
mechanical properties. However, based on the theoretical
approach on which the regression analysis was based \[ 30 \], these
three variables should explain the entire interindividual variability in performance, which was not the case here ( _r²_ = 0.931).
This diff erence can be due to measurement inaccuracies or to
the imperfect reliability of the human performance, as reported
by Hopkins \[ 17 \], where a standard error of measurement of ~7 %
for explosive movements was found. The validation of the equations used in the theoretical approach reported errors between
theoretical and experimental values of about 6 % \[ 30 \] . Moreover,
a multiple regression analysis supposed linear relationships
between dependent and independent variables, which is not
exactly the case here (equation 6 in \[ 30 \] ), and which can contribute to increasing the model error of estimate. Finally, _Pmax_
was computed using equation 3 from extrapolation of F-v curves
on force and velocity-axis instead of using the apex of the powervelocity relationship \[ 27, 33 \], the latter requiring more than 5
jumping conditions to properly model power-velocity polynomial regressions. Nevertheless, no diff erence in _Pmax_ between
these two methods has been reported with a bias lower than 2 %
\[ 30 \] . It should be noted that _Pmax_, jump height and _hPO_ values
obtained here are in line with previous studies \[ 5, 27, 28, 30 \] .
This study was based on a biomechanical approach aimed at
describing the mechanical outputs that result from the action of
the entire lower limb neuromuscular system, and not modeling
the complex musculoskeletal structures at the origin of these
outputs. The main limit of this approach could be the macroscopic level from which the multi-segmental neuromuscular
system is considered, inducing (i) the description of its mechanical external capabilities by the empirically-determined F-v relationships, and (ii) the application of principles of dynamics to a
whole body viewed as a system (these points have been discussed in detail in \[ 29, 30 \] ). The bias induced by the simplifi cations and approximations associated with this approach were
shown to be low ( \< 6 %) and trivial, which supported its validity
\[ 30 \] . This validity is also strengthened, as shown in  ● \[ ▶ \] **Fig. 3**, by
the high agreement between measured performances and theoretical changes predicted by the model. The F-v linear model
used to characterize the dynamic external capabilities of the
lower limb neuromuscular system has been previously well supported and discussed during multi-joint lower limb extensions
\[ 4, 5, 27, 30, 33 \] . These overall dynamic external capabilities are
the fi nal result of the diff erent mechanisms involved in limbs
extension, and characterize the mechanical limits of the entire
neuromuscular function in vivo. They are a complex integration
of numerous individual muscle mechanical properties (e. g.
intrinsic F-v and length-tension relationship, rate of force devel

Training & Testing

opment), some morphological factors (e. g. cross sectional area,
fascicle length, pennation angle, tendon properties, anatomical
joint confi guration), neural mechanisms (e. g. motor unit recruitment, fi ring frequency, motor unit synchronization, inter-muscular coordination) and segmental dynamics \[ 4, 7 – 9 \] . Our
approach is also based on mechanical outputs averaged over the
entire lower limb extension movement which appeared to be
more representative of the muscular eff ort analyzed than
instantaneous values \[ 2 \] . Finally, it is worth noting that this
study focused only on squat jump performance that does not
involve all mechanical and neuromuscular mechanisms participating in the more natural counter-movement jumps. Even if
one could expect to observe similar fi ndings, further studies are
currently undertaken to explore the eff ect of F-v imbalance on
such kind of jumping performance.
To conclude, this study lends experimental evidence that ballistic performance depends, in addition to _Pmax_, on the normalized
F-v profi le of lower limbs (slope of the F-v relationship) characterizing the ratio between their maximal normalized force and
maximal velocity capabilities. Even if _Pmax_ remains the main
determinant, an F-v imbalance is associated with a lower performance. This result constitutes experimental support to the
previous theoretical approach expressing ballistic performance
as a function of lower limbs mechanical properties \[ 29, 30 \], and
presents numerous direct practical applications, notably in
strength training and conditioning. Finally, this study proposes
an applied approach to accurately determine (in fi eld or laboratory conditions) both the individual maximum power output
and the F-v imbalance, which could be developed in a more general method for testing the adaptation of mechanical properties
of the lower limb neuromuscular system in a variety of maximum performance tasks.

Acknowledgements
The authors thank James de Lacey (PhD student, Auckland University of Technology, New Zealand) for assisting with the data
collection of the rugby players and all the subjects tested for
their imbalance and their powerful implication in the protocol.

**Affi liations**

1  Laboratory of Exercise Physiology (EA4338), University of Savoie, Le Bourget

du Lac, France

\[ 2 \] Department of Clinical and Exercise Physiology, Sports Medicine Unity,

University-Hospital of Saint-Etienne, France

\[ 3 \] Laboratory of Exercise Physiology (EA4338), University of Lyon, Saint

Etienne, France

\[ 4 \] Centre d’Etude des Transformations des Activités Physiques et Sportives (EA

3832), University of Rouen, France

\[ 5 \] Association Sportive de Saint-Etienne, France
6  Sports Performance Research Institute New Zealand, AUT University,

Auckland, New Zealand

References

1 _Alexander_ _RM_ . Leg design and jumping technique for humans, other

vertebrates and insects . Philos Trans R Soc Lond B Biol Sci 1995 ; 347 :
235 – 248
2 _Andrews_ _GC_ . Biomechanical measures of muscular eff ort . Med Sci

Sports Exerc 1983 ; 15 : 199 – 207
3 _Asmussen_ _E_, _Bonde-Petersen_ _F_ . Storage of elastic energy in skeletal

muscles in man . Acta Physiol Scand 1974 ; 91 : 385 – 392
4 _Bobbert_ _MF_ . Why is the force-velocity relationship in leg press tasks

quasi-linear rather than hyperbolic?  J Appl Physiol 2012, doi: 10.1152/
japplphysiol.00787.02011

Samozino P et al. Force-Velocity Profi le: Imbalance Determination … Int J Sports Med

Training & Testing

5 _Bosco_ _C_, _Belli_ _A_, _Astrua_ _M_, _Tihanyi_ _J_, _Pozzo_ _R_, _Kellis_ _S_, _Tsarpela_ _O_, _Foti_

_C_, _Manno_ _R_, _Tranquilli_ _C_ . A dynamometer for evaluation of dynamic
muscle work . Eur J Appl Physiol 1995 ; 70 : 379 – 386
6 _Cormie_ _P_, _McCaulley_ _GO_, _McBride_ _JM_ . Power versus strength-power

jump squat training: infl uence on the load-power relationship . Med
Sci Sports Exerc 2007 ; 39 : 996 – 1003
7 _Cormie_ _P_, _McGuigan_ _MR_, _Newton_ _RU_ . Adaptations in athletic perform
ance after ballistic power versus strength training . Med Sci Sports
Exerc 2010 ; 42 : 1582 – 1598
8 _Cormie_ _P_, _McGuigan_ _MR_, _Newton_ _RU_ . Infl uence of strength on magni
tude and mechanisms of adaptation to power training . Med Sci Sports
Exerc 2010 ; 42 : 1566 – 1581
9 _Cormie_ _P_, _McGuigan_ _MR_, _Newton_ _RU_ . Developing maximal neuromus
cular power: part 1 – biological basis of maximal power production .
Sports Med 2011 ; 41 : 17 – 38
10 _Cronin_ _J_, _McNair_ _PJ_, _Marshall_ _RN_ . Velocity specifi city, combination

training and sport specifi c tasks . J Sci Med Sport 2001 ; 4 : 168 – 178
11 _Cronin_ _J_, _Sleivert_ _G_ . Challenges in understanding the infl uence of maxi
mal power training on improving athletic performance . Sports Med
2005 ; 35 : 213 – 234
12 _Domire_ _ZJ_, _Challis_ _JH_ . The infl uence of squat depth on maximal vertical

jump performance . J Sports Sci 2007 ; 25 : 193 – 200
13 _Driss_ _T_, _Vandewalle_ _H_, _Monod_ _H_ . Maximal power and force-velocity

relationships during cycling and cranking exercises in volleyball players. Correlation with the vertical jump test . J Sports Med Phys Fitness
1998 ; 38 : 286 – 293
14 _Harris_ _MA_, _Steudel_ _K_ . The relationship between maximum jumping

performance and hind limb morphology/physiology in domestic cats
(Felis silvestris catus) . J Exp Biol 2002 ; 205 : 3877 – 3889
15 _Harris_ _NK_, _Cronin_ _JB_, _Hopkins_ _WG_, _Hansen_ _KT_ . Squat jump training

at maximal power loads vs. heavy loads: eff ect on sprint ability .
J Strength Cond Res 2008 ; 22 : 1742 – 1749
16 _Harriss_ _DJ_, _Atkinson_ _G_ . Update – Ethical standards in sport and exercise

science research . Int J Sports Med 2011 ; 32 : 819 – 821
17 _Hopkins_ _WG_, _Schabort_ _EJ_, _Hawley_ _JA_ . Reliability of power in physical

performance tests . Sports Med 2001 ; 31 : 211 – 234
18 _James_ _RS_, _Wilson_ _RS_ . Explosive jumping: extreme morphological and

physiological specializations of Australian rocket frogs (Litoria nasuta) . Physiol Biochem Zool 2008 ; 81 : 176 – 185
19 _Jaric_ _S_, _Markovic_ _G_ . Leg muscles design: the maximum dynamic out
put hypothesis . Med Sci Sports Exerc 2009 ; 41 : 780 – 787

20 _Kaneko_ _M_, _Fuchimoto_ _T_, _Toji_ _H_, _Suei_ _K_ . Training eff ect of diff erent loads

on the force-velocity relationship and mechanical power output in
human muscle . Scand J Sports Sci 1983 ; 5 : 50 – 55
21 _Markovic_ _G_, _Jaric_ _S_ . Positive and negative loading and mechanical

output in maximum vertical jumping . Med Sci Sports Exerc 2007 ;
39 : 1757 – 1764
22 _McBride_ _JM_, _Triplett-McBride_ _T_, _Davie_ _A_, _Newton_ _RU_ . The eff ect of

heavy- vs. light-load jump squats on the development of strength,
power, and speed . J Strength Cond Res 2002 ; 16 : 75 – 82
23 _Nedeljkovic_ _A_, _Mirkov_ _DM_, _Bozic_ _P_, _Jaric_ _S_ . Tests of muscle power out
put: the role of body size . Int J Sports Med 2009 ; 30 : 100 – 106
24 _Nuzzo_ _JL_, _McBride_ _JM_, _Dayne_ _AM_, _Israetel_ _MA_, _Dumke_ _CL_, _Triplett_ _NT_ .

Testing of the maximal dynamic output hypothesis in trained and
untrained subjects . J Strength Cond Res 2011 ; 24 : 1269 – 1276
25 _Pazin_ _N_, _Berjan_ _B_, _Nedeljkovic_ _A_, _Markovic_ _G_, _Jaric_ _S_ . Power output in

vertical jumps: does optimum loading depend on activity profi les?
Eur J Appl Physiol 2013 ; 113 : 577 – 589
26 _Pazin_ _N_, _Bozic_ _P_, _Bobana_ _B_, _Nedeljkovic_ _A_, _Jaric_ _S_ . Optimum loading for

maximizing muscle power output: the eff ect of training history . Eur
J Appl Physiol 2011 ; 111 : 2123 – 2130
27 _Rahmani_ _A_, _Viale_ _F_, _Dalleau_ _G_, _Lacour_ _JR_ . Force/velocity and power/

velocity relationships in squat exercise . Eur J Appl Physiol 2001 ; 84 :
227 – 232
28 _Samozino_ _P_, _Morin_ _JB_, _Hintzy_ _F_, _Belli_ _A_ . A simple method for measur
ing force, velocity and power output during squat jump . J Biomech
2008 ; 41 : 2940 – 2945
29 _Samozino_ _P_, _Morin_ _JB_, _Hintzy_ _F_, _Belli_ _A_ . Jumping ability: A theoretical

integrative approach . J Theor Biol 2010 ; 264 : 11 – 18
30 _Samozino_ _P_, _Rejc_ _E_, _Di Prampero_ _PE_, _Belli_ _A_, _Morin_ _JB_ . Optimal force
velocity profi le in ballistic movements. Altius, citius or fortius?  Med
Sci Sports Exerc 2012 ; 44 : 313 – 322
31 _Selbie_ _WS_, _Caldwell_ _GE_ . A simulation study of vertical jumping from

diff erent starting postures . J Biomech 1996 ; 29 : 1137 – 1146
32 _Vandewalle_ _H_, _Peres_ _G_, _Heller_ _J_, _Panel_ _J_, _Monod_ _H_ . Force-velocity rela
tionship and maximal power on a cycle ergometer. Correlation with
the height of a vertical jump . Eur J Appl Physiol Occup Physiol 1987 ;
56 : 650 – 656
33 _Yamauchi_ _J_, _Ishii_ _N_ . Relations between force-velocity characteristics

of the knee-hip extension movement and vertical jump performance .
J Strength Cond Res 2007 ; 21 : 703 – 709

Samozino P et al. Force-Velocity Profi le: Imbalance Determination … Int J Sports Med
